PartialFunctionCall

Struct PartialFunctionCall 

#[non_exhaustive]
pub struct PartialFunctionCall { pub name: Option<String>, pub arguments: Option<String>, }
Partial function call data as received in streaming deltas.

Unlike FunctionCall, all fields are optional because streaming chunks may only contain fragments of the function call (e.g., just an arguments fragment without the function name).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>arguments: Option<String>