PartialToolCall

Struct PartialToolCall 

#[non_exhaustive]
pub struct PartialToolCall { pub id: Option<String>, pub type_: Option<String>, pub function: Option<PartialFunctionCall>, pub index: Option<u32>, }
Partial tool call data as received in streaming deltas.

When the API streams a response that includes tool calls, each SSE chunk contains only a fragment of the tool call data. The first chunk typically contains id, type, and the function name, while subsequent chunks contain fragments of the arguments string.

Use ToolAwareStream to automatically accumulate these partial chunks into complete ToolCall objects.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<String>type_: Option<String>function: Option<PartialFunctionCall>index: Option<u32>