StreamEvent

Enum StreamEvent 

#[non_exhaustive]
pub enum StreamEvent { ContentDelta(String), ReasoningDelta(String), ReasoningDetailsDelta(Vec<ReasoningDetail>), Done { tool_calls: Vec<ToolCall>, finish_reason: Option<FinishReason>, usage: Option<ResponseUsage>, id: String, model: String, }, Error(OpenRouterError), }
Events emitted by ToolAwareStream.

Content and reasoning deltas are yielded immediately as they arrive. Tool calls are accumulated internally and emitted as complete objects only once in the final StreamEvent::Done event.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ContentDelta(String)

A fragment of text content from the assistant’s response.



ReasoningDelta(String)

A fragment of reasoning/chain-of-thought content.



ReasoningDetailsDelta(Vec<ReasoningDetail>)

Structured reasoning detail blocks (e.g., encrypted reasoning).



Done

The stream has finished. Contains all accumulated data.

tool_calls will be empty if the model did not invoke any tools. usage is typically only present in the final SSE chunk.

Fields

tool_calls: Vec<ToolCall>

Fully assembled tool calls (empty if none were requested).

finish_reason: Option<FinishReason>

The reason the model stopped generating.

usage: Option<ResponseUsage>

Token usage statistics (if provided by the API).

id: String

The response ID from the API.

model: String

The model that generated the response.



Error(OpenRouterError)

An error occurred while processing the stream.