#[non_exhaustive]pub struct FunctionDefinition {
pub name: String,
pub description: String,
pub parameters: Value,
pub strict: Option<bool>,
}Expand description
Function definition within a tool
Defines the function that can be called, including its name, description, and parameter schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the function
description: StringDescription of what the function does
parameters: ValueJSON Schema defining the function parameters
strict: Option<bool>Whether the model must strictly adhere to the parameter schema.
Implementations
Sourceimpl FunctionDefinition
impl FunctionDefinition
Sourcepub fn builder() -> FunctionDefinitionBuilder
pub fn builder() -> FunctionDefinitionBuilder
Create a new function definition builder