#[non_exhaustive]pub struct PartialFunctionCall {
pub name: Option<String>,
pub arguments: Option<String>,
}Expand description
Partial function call data as received in streaming deltas.
Unlike FunctionCall, all fields are optional because streaming chunks
may only contain fragments of the function call (e.g., just an arguments
fragment without the function name).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>arguments: Option<String>Trait Implementations
Sourceimpl Clone for PartialFunctionCall
impl Clone for PartialFunctionCall
Sourcefn clone(&self) -> PartialFunctionCall
fn clone(&self) -> PartialFunctionCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartialFunctionCall
impl Debug for PartialFunctionCall
Sourceimpl Default for PartialFunctionCall
impl Default for PartialFunctionCall
Sourcefn default() -> PartialFunctionCall
fn default() -> PartialFunctionCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialFunctionCall
impl<'de> Deserialize<'de> for PartialFunctionCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more