#[non_exhaustive]pub struct PartialToolCall {
pub id: Option<String>,
pub type_: Option<String>,
pub function: Option<PartialFunctionCall>,
pub index: Option<u32>,
}Expand description
Partial tool call data as received in streaming deltas.
When the API streams a response that includes tool calls, each SSE chunk
contains only a fragment of the tool call data. The first chunk typically
contains id, type, and the function name, while subsequent chunks
contain fragments of the arguments string.
Use ToolAwareStream to
automatically accumulate these partial chunks into complete ToolCall
objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>type_: Option<String>function: Option<PartialFunctionCall>index: Option<u32>Trait Implementations
Sourceimpl Clone for PartialToolCall
impl Clone for PartialToolCall
Sourcefn clone(&self) -> PartialToolCall
fn clone(&self) -> PartialToolCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartialToolCall
impl Debug for PartialToolCall
Sourceimpl Default for PartialToolCall
impl Default for PartialToolCall
Sourcefn default() -> PartialToolCall
fn default() -> PartialToolCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialToolCall
impl<'de> Deserialize<'de> for PartialToolCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more